@@ -72,6 +72,7 @@ class Character:
             The value to set it to
         """
         self.numbers[item] = value
+        self.currency = "£"
 
     def remove(self, item, value=1):
         """Remove an item or take from a number.
@@ -94,7 +95,7 @@ class Character:
             raise ValueError("item must be a string")
         return item in self.numbers
 
-    def get_inventory(self, items):
+    def get_inventory(self, items, currency):
         """Get the names of the character's inventory.
 
         Returns
@@ -108,14 +109,18 @@ class Character:
             if not item.hidden:
                 name = item.get_name(self)
                 if name is not None:
-                    inv.append(finalise(name, self.numbers) + ": " + str(n))
+                    display_name = finalise(name, self.numbers, currency)
+                    if item.id != "money" or currency is None:
+                        display_name += ": "
+                    inv.append(display_name + str(n))
         for i in self.inventory:
             if i in items:
                 item = items[i]
                 if not item.hidden:
                     name = item.get_name(self)
                     if name is not None:
-                        inv.append(finalise(item.get_name(self), self.numbers))
+                        inv.append(finalise(item.get_name(self), self.numbers,
+                                            currency))
         return [i for i in inv if i is not None and i != ""]
 
 
@@ -167,7 +172,9 @@ class Game:
         self.active = active
         self.version = version
         self.ave_version = tuple(ave_version)
+        self.currency = None
         self.rooms = None
+        self.items = None
 
         self.options = []
 
@@ -184,6 +191,11 @@ class Game:
         else:
             raise ValueError("One of url and file must be set to load a game.")
 
+        if "money" in self.items:
+            c = self.items["money"].names[0].text
+            if c in ["$", "£"]:
+                self.currency = c
+
     def __getitem__(self, id):
         """Get a room with given id."""
         return self.load_room(id)
@@ -214,7 +226,7 @@ class Game:
         o.get_items(character)
         character.location = o.get_destination()
 
-    def get_room_info(self, character):
+    def get_room_info(self, character, currency):
         """Get the information about the character's current room.
 
         Parameters
@@ -230,9 +242,9 @@ class Game:
             The available destination options that the character could take
         """
         room = self[character.location]
-        text = room.get_text(character)
+        text = room.get_text(character, currency)
         options = room.get_options(character)
-        return text, {i: finalise(o.text, character.numbers)
+        return text, {i: finalise(o.text, character.numbers, currency)
                       for i, o in options.items()}
 
     def fail_room(self):
@@ -257,7 +269,7 @@ class Room:
         """Return a string."""
         return "Room with id " + self.id
 
-    def get_text(self, character):
+    def get_text(self, character, currency):
         """Get the text for the room.
 
         Parameters
@@ -275,7 +287,8 @@ class Room:
             if line.has_requirements(character):
                 line.get_items(character)
                 lines.append(line.text)
-        return finalise(" ".join(lines), character.numbers)
+        return finalise(" ".join([i for i in lines if i != ""]),
+                        character.numbers, currency)
 
     def get_options(self, character):
         """Get the character's current destination options.
